@@ -14,7 +14,6 @@
 
 set_time_helper::set_time_helper()
 {
-	Genode::log("set_time_helper::ctor");
 }
 
 
@@ -45,14 +44,12 @@ void set_time_helper::set_time(time_t &time)
 		Genode::error("time is not in UTC!");
 	}
 
-	Genode::error(__func__, ":", __LINE__, ": ts: ", _ts);
 	_set_rtc(*_set_time_reporter, _ts);
 }
 
 
 set_time_helper* set_time_callback_function(set_time_helper* set_time_helper, time_t time)
 {
-	Genode::error(__func__, ":", __LINE__, ": time: ", time);
 	set_time_helper->set_time(time);
 	return set_time_helper;
 }
